# Threadable

::: torchlinops.linops.Threadable
    options:
        inherited_members: false
        members:
            - __init__
            - linops
            - threaded_apply
            - threaded_apply_sum_reduce
            - settings